@@ -26,9 +26,11 @@ from shrike.compliant_logging.data_conversions import (
     numpy_array_to_list,
     pandas_series_to_list,
 )
+from shrike._core import is_eyesoff_helper
 from datetime import datetime
 import logging
 import sys
+import os
 from threading import Lock
 
 
@@ -969,6 +971,15 @@ class CompliantLogger(logging.getLoggerClass()):  # type: ignore
         self.metric(value=value, name=name, description=description, category=category)
 
 
+def is_eyesoff() -> bool:
+    """
+    Returns a boolean of whether current workspace is eyes-off.
+    """
+    tenant_id = os.environ.get("AZ_BATCHAI_CLUSTER_TENANT_ID", "")
+    subscription_id = os.environ.get("AZ_BATCHAI_CLUSTER_SUBSCRIPTION_ID", "")
+    return is_eyesoff_helper(tenant_id, subscription_id)
+
+
 _logging_basic_config_set_warning = """
 ********************************************************************************
 The root logger already has handlers set! As a result, the behavior of this
